@@ -24,12 +24,15 @@ class TranslationManager(object):
         self.options = {
             'locales': [],
             'auto_create_locales': True,
+            'base_classes': None,
+            'table_name': '%s_translation',
+            'locale_column_name': 'locale',
         }
 
     def instrument_translatable_classes(self, mapper, cls):
         if issubclass(cls, Translatable):
             if (not cls.__translatable__.get('class')
-                    and cls not in cls.__pending_translatables__):
+                    and cls not in self.pending_classes):
                 self.pending_classes.append(cls)
 
     def configure_translatable_classes(self):
@@ -81,6 +84,7 @@ class TranslationManager(object):
                     viewonly=True
                 )
             )
+
         setattr(
             translation_cls,
             'translation_parent',
